ort-package: ort: Create a Data Frame Representation of an Image

ort-packageR Documentation

ort: Create a Data Frame Representation of an Image

Description

Takes images, imported via 'imager', and converts them into a data frame that can be plotted to look like the imported image. This can be used for creating data that looks like a specific image. Additionally, images with color and alpha channels can be converted to grayscale in preparation for converting to the data frame format.

Author(s)

Maintainer: Ethan C. Brown ethancbrown@gmail.com (Maintainer)

Authors:

  • Falling Pineapples (Original author)


ort documentation built on Feb. 23, 2026, 5:08 p.m.