| ort-package | R Documentation |
Takes images, imported via 'imager', and converts them into a data frame that can be plotted to look like the imported image. This can be used for creating data that looks like a specific image. Additionally, images with color and alpha channels can be converted to grayscale in preparation for converting to the data frame format.
Maintainer: Ethan C. Brown ethancbrown@gmail.com (Maintainer)
Authors:
Falling Pineapples (Original author)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.